@@ -6,7 +6,7 @@ def hub(hub):
     """
     provides a full hub that is used as a reference for mock_hub
     """
-    hub.pop.sub.add(dyne_name="corn")
+    hub.pop.sub.add(dyne_name="grains")
     hub.pop.sub.add(dyne_name="exec")
 
     yield hub
@@ -15,12 +15,12 @@ def hub(hub):
 @pytest.fixture(scope="function")
 def mock_hub(hub, mock_hub):
     """
-    A hub specific to corn unit testing
-    Scope is function so that CORN values are clean with every run
+    A hub specific to grains unit testing
+    Scope is function so that grains values are clean with every run
     """
-    mock_hub.corn.init.clean_value = hub.corn.init.clean_value
-    mock_hub.corn.CORN = hub.pop.data.omap()
+    mock_hub.grains.init.clean_value = hub.grains.init.clean_value
+    mock_hub.grains.GRAINS = hub.pop.data.omap()
 
     yield mock_hub
 
-    del mock_hub.corn.CORN
+    del mock_hub.grains.GRAINS
